function [generationOverTime,modelledRange] = SolveBigAllSpecies(PCVValue,HistCV)

    fprintf('Solving model with pcv=%d, Hist CV in ALL Networks: %d\n',PCVValue,HistCV);
    clearvars -except PCVValue HistCV;
    Blimp1Threshold=4;
    AIDThreshold=4;
    maxGens = 8;
    maxTime=248*60;  % minutes
    N=250;  % starting cells
    replicates = 3;

    poolobj = gcp('nocreate');
    delete(poolobj);
    if isempty(gcp('nocreate'))
        parpool('local',32);
    end

 
    paramsToRun = {};
    paramNames = {};
    

    

     %%%%%%%%%%%%% Parameter DESCRIPTION %%%%%%%%%%%%%%
     % NFKB_CYCD_T NFKB_BCL2_T  NFKB_MYC_T    GROWTH_T  
     % RATE_CV CONC_CV PARTITION_CV VOL_CV IKK_CV  
     % GMSyn  GMDeg  MassGrowth MassDecay 
     % CYCDtSyn CYCDtDeg BCL2Syn BCL2tDeg 
     % MYCSyn MYCDeg mMycSyn mMycDeg L
     % IKK STIMULUS, Crel monomer,cRelFeedback,eps (Ribosome modifier)
     %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%      
    parameters= {'CD_T';'BCL_T';'MYC_T';'GROW_T';'RCV';'CCV';
        'PCV';'VCV';'IKKCV';'GMSyn';'GMDeg';'MGrow';'MDeg';'CDtSyn';'CDtDeg';
        'BCLtSyn';'BCLtDeg';'MYCSyn';'MYCDeg';'MYCtSyn';'MYCtDeg';'L';
        'IKK Fxn';'Crel?';'NFkBFbck';'EPS';'IKKTotal'};
    
 paramsToRun{end+1}=[40;40;40;40;         % CYCDT BCLT MYCT GROWT
        PCVValue;0.00;0.00;0.00;0.00 ;    % RCV CCV PCV VCV IKKCV
        0.002; 0.0002 ;0.004; 0.002;     % GMSyn GMDeg MGrow MDeg
        
        0.0030;0.002;13;0.007;            % CYCDtSyn CYCDtDeg BCL2tSyn BCL2tDeg 
        0.0040;0.0020;1;0.0231;1;         % MYCSyn MYCDeg mMycSyn mMycDeg L
        3;1;10;1;170;                     % IKK input (see intial_parameters8.m), cRel present?, NFkB induction modifier, translation modifier, IKK total (nM)
        HistCV;0;Blimp1Threshold; AIDThreshold];                              %history RCV CCV AIDThresh BlimpThresh
     parameterSetName=strcat('rep1IKK-170-','PCV',num2str(PCVValue),'-HCV',num2str(HistCV),'-AllNoise-',num2str(N),'Cells-WT');
     paramNames{end+1}=parameterSetName;

    for k = 1:numel(paramsToRun)
        experiment = randomCondition(maxTime,paramsToRun{k});
        solutions ={};

        for rep = 1:replicates
            label = sprintf('%s_%d',paramNames{k},rep);
            for i = 1:length(parameters)
                label= sprintf('%s %s=%2.2f',label,parameters{i},paramsToRun{k}(i));
            end
            solutions{end+1}=runSolution(experiment,N,maxTime,maxGens);
            
            experiment_label=sprintf('%s_%d %s',paramNames{k},rep,datestr(now,'mmmm dd, yyyy HH-MM-SS-FFF'));
        end
        
        saveSolutions(solutions,N,maxTime,maxGens,paramNames{k},label);
        modelledRange=solutions{end}.rangeDistribution;

        generationOverTime=solutions{end}.generationsOverTime;

    end

    poolobj = gcp('nocreate');
    delete(poolobj);

    clearvars -except modelledRange generationOverTime;
    
    system('rm -rf unprocessedCells*');
    system('rm -rf processedCells*');
    system('rm -rf Checkpoints*');
end

function sol= runSolution(experiment, N, maxTime, maxGens)
    SEE = 0;   
    
    sol = duplicate(experiment);    
    sol.counts=ones(ceil(maxTime/30),maxGens);
    sol.fullCounts = zeros(maxTime,maxGens); % total count as a function of gen and time
    sol.integralCounts = zeros(maxGens); % total number of generation cells
    sol.h24counts = zeros(maxGens); % total number of generation cells
    sol.raverages = zeros(100,144,maxGens);
    sol.qaverages = zeros(100,144,maxGens);
    sol.Tdivs= zeros(maxGens,ceil(maxTime/60)); % in terms of hours
    sol.Tdecides = zeros(maxGens,ceil(maxTime/60));
    sol.Tdies= zeros(maxGens,ceil(maxTime/60));
    sol.TdivTimes = cell(1);
    sol.TdieTimes = cell(1);
    sol.TdecideTimes = cell(1);
    sol.TdivMothers = cell(1);
    sol.TdieMothers = cell(1);
    sol.TdecideMothers = cell(1);    
    for i = 1:maxGens
    sol.TdivTimes{end+1}=cell(1);
    sol.TdieTimes{end+1}=cell(1);
    sol.TdecideTimes{end+1}=cell(1);
    sol.TdivMothers{end+1}=cell(1);
    sol.TdieMothers{end+1}=cell(1);
    sol.TdecideMothers{end+1}=cell(1);
    end

    sol.divbag = {};
    sol.diebag ={};
    sol.decidebag = {};

    sol.gs = zeros(maxGens); % fraction that grow to larger than v0+1.75 their starting size or to a size of 4 (both dividers and non-dividers)
    sol.fs = zeros(maxGens); % fraction that divides (assume that the rest will eventually die)
    sol.tp = zeros(maxGens); % fraction that grows and divides
    sol.fp = zeros(maxGens); % fraction that grows but dies
    sol.tn = zeros(maxGens); % fraction that doesn't grow and dies
    sol.fn = zeros(maxGens); % fraction that doesn't grow but divides
    sol.tp24 = zeros(maxGens); % fraction that grows and divides 24
    sol.fp24 = zeros(maxGens); % fraction that grows but dies 24
    sol.tn24 = zeros(maxGens); % fraction that doesn't grow and dies 24
    sol.fn24 = zeros(maxGens); % fraction that doesn't grow but divides 24


    sol.RelA50n=zeros(ceil(maxTime/30)+1,N);
    sol.cRel50n=zeros(ceil(maxTime/30)+1,N);
    sol.RelA50Total=zeros(ceil(maxTime/30)+1,N);
    sol.cRel50Total=zeros(ceil(maxTime/30)+1,N);
    sol.RelAn=zeros(ceil(maxTime/30)+1,N);
    sol.cReln=zeros(ceil(maxTime/30)+1,N);
    sol.RelATotal=zeros(ceil(maxTime/30)+1,N);
    sol.cRelTotal=zeros(ceil(maxTime/30)+1,N);
    sol.BclXL=zeros(ceil(maxTime/30)+1,N);
    sol.CYCD=zeros(ceil(maxTime/30)+1,N);
    sol.Myc=zeros(ceil(maxTime/30)+1,N);
    sol.IkBa=zeros(ceil(maxTime/30)+1,N);
    sol.IkBb=zeros(ceil(maxTime/30)+1,N);
    sol.IkBe=zeros(ceil(maxTime/30)+1,N);
    sol.IkBd=zeros(ceil(maxTime/30)+1,N);
    sol.Mass=zeros(ceil(maxTime/30)+1,N);
    sol.cParp=zeros(ceil(maxTime/30)+1,N);
    sol.Parp=zeros(ceil(maxTime/30)+1,N);
    sol.c3Parp=zeros(ceil(maxTime/30)+1,N);
    sol.cdh1=zeros(ceil(maxTime/30)+1,N);
    sol.IRF4=zeros(ceil(maxTime/30)+1,N);
    sol.AID=zeros(ceil(maxTime/30)+1,N);
    sol.Blimp=zeros(ceil(maxTime/30)+1,N);
    sol.Bach2=zeros(ceil(maxTime/30)+1,N);
    sol.generationsOverTime=zeros(ceil(maxTime/3),maxGens);


    %Need to store lineage tree information for plotting modeling lineage trees.
    %CellID, motherID fateTime aidUp aiddown blimp
    sol.lineageInfo=zeros(6,N);

    %save max min and range distribution for fitting to tracked data
    sol.minGenDistribution=zeros(N,1);
    sol.maxGenDistribution=zeros(N,1);
    sol.rangeDistribution=zeros(N,1);

    
    
    vo = initial_parameters8(experiment);
    %all of the cells currently waiting to be computed
    cells = cell(N,1);


    totalCellNumberCurrentlyProcessed=1;
    
    TdivFits = zeros(maxGens,6); %lognormal fits: E[Tdiv]fit, s.d.[Tdiv]fit, E[Tdiv]min, E[Tdiv]max, s.d.[Tdiv]min, s.d.[Tdiv]max
    TdieFits = zeros(maxGens,6);
    optionsDiv  = odeset('AbsTol',1E-5,'RelTol',1E-3,'Events',@division);

    %initialize to equalibrium
    
    parfor i=1:N  
        dividing    = true;    % True if at equilibrium
        v = initial_parameters8(experiment);
        v= getRandomCell(v);

        nfkbDivDeath_ode_cRel([],[],[],v);

        v.SPECIES{1}(62) = 0;
        v.SPECIES{1}(v.SPECIES{1}(1:144)<1e-7) = 0;


        v.k2(77)= 1; 
        dcount = 0;
        while dividing
            [t,x,te,ye,ie]=ode15s(@(t,x) nfkbDivDeath_ode_cRel(t,x,[],v), [0 24*60], v.SPECIES{1},optionsDiv);
            if ie ==2
                x(end,(numel(v.SPECIES{1})-v.CELL_CYCLE+15))=x(end,(numel(v.SPECIES{1})-v.CELL_CYCLE+15))/2;
                x(end,(numel(v.SPECIES{1})-v.CELL_CYCLE+13))=x(end,(numel(v.SPECIES{1})-v.CELL_CYCLE+13))/2;
                x(end,126)=1; 
                dcount=dcount+1;

            else
                dividing = false;
            end
            v.SPECIES{1} = x(end,:);
            v.OUTPUT1 = [v.OUTPUT1;x];
        end
        v.SPECIES{1} = v.OUTPUT1(end,:)';
        if experiment.VOL_CV > 0
            factor = max(0,normrnd(1,experiment.VOL_CV));
            v.SPECIES{1}(134)=v.SPECIES{1}(134)*factor;
            v.SPECIES{1}(132) =v.SPECIES{1}(132)*factor;
        end
        v.SPECIES{1}(62) = experiment.L;
        v.SPECIES{1}(145:end)=0;
        v.SPECIES{1}(147)=1;
        v.k2(77) = experiment.EPS;

        cells{i}.v=v;
        cells{i}.v.PHASE = 2;
        cells{i}.x = v.SPECIES{1};
        cells{i}.birthday=0;  % start at 0 hours
        cells{i}.gen = 1;  % undivided
        cells{i}.id =i;
        cells{i}.parent =0;
        cells{i}.maxgen=maxGens;
        cells{i}.founder=i;
        cells{i}.tAIDUp=0;
        cells{i}.tBlimpUp=0;
        cells{i}.tAIDDown=0;
    end
        mkdir('unprocessedCells');
        mkdir('processedCells');
        save('-v7.3','unprocessedCells/cells.mat','cells');
    steadyStateMatrix=zeros(length(cells{1}.v.SPECIES{1}),N);
    for i=1:N
        steadyStateMatrix(:,i)=cells{i}.v.SPECIES{1};
    end
        experiment_label=sprintf('%s_%d %s',datestr(now,'mmmm dd, yyyy HH-MM-SS-FFF'));
        fid = fopen(strcat(experiment_label,'PreStimulusMetabolites.CSV'),'w');
        fprintf(fid, '%s,',cells{1}.v.SPECIES{2}{1:end});
        fprintf(fid, '\n');
        fclose(fid);
        dlmwrite(strcat(experiment_label,'PreStimulusMetabolites.CSV'),steadyStateMatrix','-append');



    cell_id=N+1;
    
    mkdir('Checkpoints');
    
    while ~isempty(dir(fullfile('unprocessedCells','*.mat')))
        

        filesToProcess=fullfile('unprocessedCells','*.mat');
        cellsToProcess=dir(filesToProcess);
            

        for k=1:length(cellsToProcess)
            load(fullfile('unprocessedCells',cellsToProcess(k).name));
            
            if length(cells)==0
                mkdir('EmptyCells');
                movefile(fullfile('unprocessedCells',cellsToProcess(k).name),fullfile('EmptyCells',cellsToProcess(k).name));
                continue;
            end
            stridelength=ceil(length(cells)/100);
            for stride=1:stridelength
                celllength = min(100,length(cells)-(stride-1)*100);
                parfor temporary=((stride-1)*100+1):((stride-1)*100)+celllength                   
                    cells{temporary}.v.SIM_TIME=max(1,(maxTime)-cells{temporary}.birthday);
                    cells{temporary}.v.START_TIME = cells{temporary}.birthday;
                    if cells{temporary}.gen == maxGens;
                        cells{temporary}.v=run_cell(cells{temporary}.v,true);
                    else
                        cells{temporary}.v=run_cell(cells{temporary}.v,false);
                    end
                    tdiv = 999999;
                    tdie = 999999;
                    tdecide=999999;
                    if cells{temporary}.v.EVENT==1    % the cell must have died
                        tdie=cells{temporary}.v.SIM_TIME;    
                    elseif cells{temporary}.v.EVENT==2
                        tdiv=cells{temporary}.v.SIM_TIME;
                    else
                    end
                    cells{temporary}.grew=0;
                    if numel(cells{temporary}.v.OUTPUT2) > 0 && (cells{temporary}.v.OUTPUT2(end,134) > cells{temporary}.v.OUTPUT2(1,134)+2 || cells{temporary}.v.OUTPUT2(end,134) > 4.7)
                        tdecide=find(cells{temporary}.v.OUTPUT2(:,134)>cells{temporary}.v.OUTPUT2(1,134)*1.05,1,'first');
                        cells{temporary}.grew = 1;
                    end
                    cells{temporary}.x = cells{temporary}.v.OUTPUT2(end,:);   % save the last concentrations

                    cells{temporary}.xc = cells{temporary}.v.OUTPUT2;   % save the entire trajectory?
                    
                    cells{temporary}.tdiv = tdiv;
                    cells{temporary}.tdie = tdie;
                    cells{temporary}.tdecide= tdecide;
                    
                    timeAIDUp=find(cells{temporary}.v.OUTPUT2(:,end)>cells{temporary}.v.AIDThreshold,1,'first');
                    if(length(timeAIDUp)<1)
                        timeAIDUp=0;
                    end
                    timeAIDDown=find(cells{temporary}.v.OUTPUT2(:,end)<cells{temporary}.v.AIDThreshold,1,'first');
                    if(length(timeAIDDown)<1)
                        timeAIDDown=0;
                    end
                    timeBLIMPUp=find(cells{temporary}.v.OUTPUT2(:,end-3)>cells{temporary}.v.BLIMP1Threshold,1,'first');
                    if(length(timeBLIMPUp)<1)
                        timeBLIMPUp=0;
                    end
                    cells{temporary}.tAIDUp=timeAIDUp;
                    cells{temporary}.tAIDDown=timeAIDDown;
                    cells{temporary}.tBlimpUp=timeBLIMPUp;
                    
                end
            end
            cells2={};    
            cell_count = 0;
            real_count = 0;
            a_mass = 0;
            a_cparp=0;
            a_CD=0;
            a_GM=0;
            a_cRel=0;
            a_RelA=0;
            a_myc=0;
            a_bcl2=0;
            numdivs = 0;
            numdeaths = 0;
            numdecides = 0;
            numRelAPositive = 0;
            numcRelPositive = 0;
            sol.deaths = [];
            sol.divs = [];
            sol.decides = [];
            dividers = 0;
            nondividers = 0;
            Cgen = 0;        
        

            while ~isempty(cells)
                theCell = cells{1};
                a_mass=a_mass+theCell.x(134);
                a_cparp = a_cparp+theCell.x(84);
                a_CD = a_CD+theCell.x(122);
                a_GM = a_GM+theCell.x(132);
                a_RelA = a_RelA+theCell.x(33);
                a_cRel = a_cRel+theCell.x(53);
                a_myc=a_myc+theCell.x(143);
                a_bcl2=a_bcl2+theCell.x(94);
                
                


                real_count=real_count+1;

                sol.integralCounts(theCell.gen)=sol.integralCounts(theCell.gen)+1;
                bindex=ceil(theCell.birthday); % birth index
                index = ceil(theCell.v.SIM_TIME);    % length of the time course
                Cgen = theCell.gen;
                for i=((bindex)+1):30:index+bindex % for each time point in the timecourse
                    if i-bindex > 0 && i <= maxTime  
                        sol.counts(ceil(i/30),theCell.gen)=sol.counts(ceil(i/30),theCell.gen)+1; % add the counts to the summary
                    end
                end
                for i=((bindex)+1):1:(index+bindex) % for each time point in the timecourse
                    if i-bindex > 0 && i <= maxTime  
                        sol.fullCounts(i,theCell.gen)=sol.fullCounts(i,theCell.gen)+1; % add the counts to the summary
                    end
                end
                if theCell.tdecide <= maxTime;
                    sol.Tdecides(theCell.gen,ceil(theCell.tdecide/60))=sol.Tdecides(theCell.gen,ceil(theCell.tdecide/60))+1;
                    sol.decides(end+1)=ceil(theCell.tdecide/60);
                    sol.gs(theCell.gen)=sol.gs(theCell.gen)+1;
                    numdecides=numdecides+1;
                end
                
                startPosition=ceil(bindex/3)+1;
                endPosition=(startPosition+ceil(index/3));
                if startPosition<1
                    startPosition=1;
                end
                if endPosition>length(sol.generationsOverTime)
                    endPosition=length(length(sol.generationsOverTime));
                end
                onesToAdd=ones(endPosition-startPosition,1);
                
                sol.generationsOverTime(startPosition:(endPosition-1),Cgen)=sol.generationsOverTime(startPosition:(endPosition-1),Cgen)+onesToAdd;

                if (theCell.tdie <= theCell.tdiv)
 
                    if theCell.tdie+1+bindex > maxTime
                        theCell.tdie=(maxTime-bindex);
                    end
                    
                    numdeaths= numdeaths+1;
                    sol.Tdies(theCell.gen,ceil(theCell.tdie/60))=sol.Tdies(theCell.gen,ceil(theCell.tdie/60))+1;
                    sol.deaths(end+1)=ceil(theCell.tdie/60);
                    if theCell.grew
                        sol.fp(theCell.gen) = sol.fp(theCell.gen)+1;
                        if (theCell.tdie < 36*60 &&theCell.tdie > 12*60) || (theCell.gen == 1 && (theCell.tdie < 48*60 &&theCell.tdie > 24*60))
                            sol.fp24(theCell.gen) = sol.fp24(theCell.gen) +1;
                            sol.h24counts(theCell.gen) = sol.h24counts(theCell.gen) +1;
                        end
                        sol.TdecideTimes{theCell.gen}{end+1}=theCell.tdecide;
                        sol.TdecideMothers{theCell.gen}{end+1}=theCell.parent;
                    else
                        sol.tn(theCell.gen) = sol.tn(theCell.gen)+1;
                        if (theCell.tdie < 36*60 &&theCell.tdie > 12*60) || (theCell.gen == 1 && (theCell.tdie < 48*60 &&theCell.tdie > 24*60))
                            sol.tn24(theCell.gen) = sol.tn24(theCell.gen) +1;
                            sol.h24counts(theCell.gen) = sol.h24counts(theCell.gen) +1;
                        end
                    end
                    for s=1:144
                        if size(theCell.v.OUTPUT2,1) > 100
                            for i = 1:1:100
                                sol.qaverages(i,s,theCell.gen)=sol.qaverages(i,s,theCell.gen)+theCell.v.OUTPUT2(ceil((size(theCell.v.OUTPUT2,1)*i)/100),s);
                            end
                        else
                            for i = 1:1:100
                                j=ceil((i*size(theCell.v.OUTPUT2,1))/100.0);
                                sol.qaverages(i,s,theCell.gen)=sol.qaverages(i,s,theCell.gen)+theCell.v.OUTPUT2(j,s);
                            end
                        end
                    end
                    sol.TdieTimes{theCell.gen}{end+1}=theCell.tdie;
                    sol.TdieMothers{theCell.gen}{end+1}=theCell.parent;
                    nondividers=nondividers+1;
                    cells(1)=[];
                    

                    RelA50nIndex=33;
                    cRel50nIndex=53;
                    RelA50TotalIndex=[32:41];
                    cRel50TotalIndex=[52:61];
                    RelAnIndex=[15,23:2:41];
                    cRelnIndex=[21,53:2:61];
                    RelATotalIndex=[14,15,22:41];
                    cRelTotalIndex=[20,21,52:61];
                    BclXLIndex=[61+33];
                    CYCDIndex=[61+58+3];
                    MycIndex=[61+58+24];
                    IkBaIndex=[1];
                    IkBbIndex=[4];
                    IkBeIndex=[7];
                    IkBdIndex=[10];
                    MassIndex=[61+28+15];
                    cParpIndex=[84];
                    ParpIndex=[82];
                    c3ParpIndex=[83];
                    cdh1Index=[126];
                    AIDIndex=[149];
                    IRFIndex=[145];
                    Blimp1Index=[146];
                    Bach2Index=[148];

                    if totalCellNumberCurrentlyProcessed+length(cellsToProcess)>size(sol.RelA50n,2)
                    sol=increaseTimeCourseLength(sol,cellsToProcess);
                    end


                    ceil(theCell.birthday/30);
                    ceil(theCell.tdie/30);
                    totalCellNumberCurrentlyProcessed;
                    RelA50nIndex;
                    size(sum(theCell.v.OUTPUT2(1:30:end,RelA50nIndex),2));
                    birthday=ceil(theCell.birthday/30);
                    birthday=birthday+1;
                    deathTime=size(sum(theCell.v.OUTPUT2(1:30:end,RelA50nIndex),2),1)+birthday;
                    if size(sum(theCell.v.OUTPUT2(1:30:end,RelA50nIndex),2),1)+1==size(birthday:deathTime,2)
                        deathTime=deathTime-1;
                    end
                    try
                        sol.RelA50n(birthday:deathTime,totalCellNumberCurrentlyProcessed)=sum(theCell.v.OUTPUT2(1:30:end,RelA50nIndex),2);
                    catch ME
                        try
                            deathTime=deathTime+1;
                            sol.RelA50n(birthday:deathTime,totalCellNumberCurrentlyProcessed)=sum(theCell.v.OUTPUT2(1:30:end,RelA50nIndex),2);
                        catch ME2
                            rethrow(ME);
                        end
                        
                        rethrow(ME);
                    end
                    changed=false;
                    
                    if(theCell.gen>sol.maxGenDistribution(theCell.founder))
                        sol.maxGenDistribution(theCell.founder)=theCell.gen;
                        changed=true;
                    end
                    if((sol.minGenDistribution(theCell.founder)==0)||theCell.gen<sol.minGenDistribution(theCell.founder))
                        sol.minGenDistribution(theCell.founder)=theCell.gen;
                        changed=true;
                    end
                    if(changed)
                         sol.rangeDistribution(theCell.founder)=sol.maxGenDistribution(theCell.founder)-sol.minGenDistribution(theCell.founder);
                    end
                        
                    sol.RelA50n(end,totalCellNumberCurrentlyProcessed)=theCell.gen;
                    sol.cRel50n(birthday:deathTime,totalCellNumberCurrentlyProcessed)=sum(theCell.v.OUTPUT2(1:30:end,cRel50nIndex),2);
                    sol.cRel50n(end,totalCellNumberCurrentlyProcessed)=theCell.gen;
                    sol.RelA50Total(birthday:deathTime,totalCellNumberCurrentlyProcessed)=sum(theCell.v.OUTPUT2(1:30:end,RelA50TotalIndex),2);
                    sol.RelA50Total(end,totalCellNumberCurrentlyProcessed)=theCell.gen;
                    sol.cRel50Total(birthday:deathTime,totalCellNumberCurrentlyProcessed)=sum(theCell.v.OUTPUT2(1:30:end,cRel50TotalIndex),2);
                    sol.cRel50Total(end,totalCellNumberCurrentlyProcessed)=theCell.gen;
                    sol.RelAn(birthday:deathTime,totalCellNumberCurrentlyProcessed)=sum(theCell.v.OUTPUT2(1:30:end,RelAnIndex),2);
                    sol.RelAn(end,totalCellNumberCurrentlyProcessed)=theCell.gen;
                    sol.cReln(birthday:deathTime,totalCellNumberCurrentlyProcessed)=sum(theCell.v.OUTPUT2(1:30:end,cRelnIndex),2);
                    sol.cReln(end,totalCellNumberCurrentlyProcessed)=theCell.gen;
                    sol.RelATotal(birthday:deathTime,totalCellNumberCurrentlyProcessed)=sum(theCell.v.OUTPUT2(1:30:end,RelATotalIndex),2);
                    sol.RelATotal(end,totalCellNumberCurrentlyProcessed)=theCell.gen;
                    sol.cRelTotal(birthday:deathTime,totalCellNumberCurrentlyProcessed)=sum(theCell.v.OUTPUT2(1:30:end,cRelTotalIndex),2);
                    sol.cRelTotal(end,totalCellNumberCurrentlyProcessed)=theCell.gen;
                    sol.BclXL(birthday:deathTime,totalCellNumberCurrentlyProcessed)=sum(theCell.v.OUTPUT2(1:30:end,BclXLIndex),2);
                    sol.BclXL(end,totalCellNumberCurrentlyProcessed)=theCell.gen;
                    sol.CYCD(birthday:deathTime,totalCellNumberCurrentlyProcessed)=sum(theCell.v.OUTPUT2(1:30:end,CYCDIndex),2);
                    sol.CYCD(end,totalCellNumberCurrentlyProcessed)=theCell.gen;
                    sol.Myc(birthday:deathTime,totalCellNumberCurrentlyProcessed)=sum(theCell.v.OUTPUT2(1:30:end,MycIndex),2);
                    sol.Myc(end,totalCellNumberCurrentlyProcessed)=theCell.gen;
                    sol.IkBa(birthday:deathTime,totalCellNumberCurrentlyProcessed)=sum(theCell.v.OUTPUT2(1:30:end,IkBaIndex),2);
                    sol.IkBa(end,totalCellNumberCurrentlyProcessed)=theCell.gen;
                    sol.IkBb(birthday:deathTime,totalCellNumberCurrentlyProcessed)=sum(theCell.v.OUTPUT2(1:30:end,IkBbIndex),2);
                    sol.IkBb(end,totalCellNumberCurrentlyProcessed)=theCell.gen;
                    sol.IkBe(birthday:deathTime,totalCellNumberCurrentlyProcessed)=sum(theCell.v.OUTPUT2(1:30:end,IkBeIndex),2);
                    sol.IkBe(end,totalCellNumberCurrentlyProcessed)=theCell.gen;
                    sol.IkBd(birthday:deathTime,totalCellNumberCurrentlyProcessed)=sum(theCell.v.OUTPUT2(1:30:end,IkBdIndex),2);
                    sol.IkBd(end,totalCellNumberCurrentlyProcessed)=theCell.gen;
                    sol.Mass(birthday:deathTime,totalCellNumberCurrentlyProcessed)=sum(theCell.v.OUTPUT2(1:30:end,MassIndex),2);                    
                    sol.Mass(end,totalCellNumberCurrentlyProcessed)=theCell.gen;

                    sol.cParp(birthday:deathTime,totalCellNumberCurrentlyProcessed)=sum(theCell.v.OUTPUT2(1:30:end,cParpIndex),2);
                    sol.cParp(end,totalCellNumberCurrentlyProcessed)=theCell.gen;
                    sol.Parp(birthday:deathTime,totalCellNumberCurrentlyProcessed)=sum(theCell.v.OUTPUT2(1:30:end,ParpIndex),2);
                    sol.Parp(end,totalCellNumberCurrentlyProcessed)=theCell.gen;
                    sol.c3Parp(birthday:deathTime,totalCellNumberCurrentlyProcessed)=sum(theCell.v.OUTPUT2(1:30:end,c3ParpIndex),2);
                    sol.c3Parp(end,totalCellNumberCurrentlyProcessed)=theCell.gen;
                    sol.cdh1(birthday:deathTime,totalCellNumberCurrentlyProcessed)=sum(theCell.v.OUTPUT2(1:30:end,cdh1Index),2);
                    sol.cdh1(end,totalCellNumberCurrentlyProcessed)=theCell.gen;

                    sol.IRF4(birthday:deathTime,totalCellNumberCurrentlyProcessed)=sum(theCell.v.OUTPUT2(1:30:end,IRFIndex),2);
                    sol.IRF4(end,totalCellNumberCurrentlyProcessed)=theCell.gen;                    
                    sol.AID(birthday:deathTime,totalCellNumberCurrentlyProcessed)=sum(theCell.v.OUTPUT2(1:30:end,AIDIndex),2);
                    sol.AID(end,totalCellNumberCurrentlyProcessed)=theCell.gen;                    
                    sol.Blimp(birthday:deathTime,totalCellNumberCurrentlyProcessed)=sum(theCell.v.OUTPUT2(1:30:end,Blimp1Index),2);
                    sol.Blimp(end,totalCellNumberCurrentlyProcessed)=theCell.gen;
                    sol.Bach2(birthday:deathTime,totalCellNumberCurrentlyProcessed)=sum(theCell.v.OUTPUT2(1:30:end,Bach2Index),2);
                    sol.Bach2(end,totalCellNumberCurrentlyProcessed)=theCell.gen;

                    sol.lineageInfo(1,totalCellNumberCurrentlyProcessed)= theCell.id;
                    sol.lineageInfo(2,totalCellNumberCurrentlyProcessed)=theCell.parent;
                    sol.lineageInfo(3,totalCellNumberCurrentlyProcessed)=theCell.birthday+theCell.tdie;
                    size(sol.lineageInfo)
                    sol.lineageInfo(4, totalCellNumberCurrentlyProcessed)= theCell.tAIDUp;
                    sol.lineageInfo(5, totalCellNumberCurrentlyProcessed)= theCell.tAIDDown;
                    sol.lineageInfo(6, totalCellNumberCurrentlyProcessed)= theCell.tBlimpUp;

                    totalCellNumberCurrentlyProcessed=totalCellNumberCurrentlyProcessed+1;
                    
                    
                else
                    if theCell.tdiv+1+bindex>maxTime
                        theCell.tdiv=maxTime-bindex;    

                    end

                    cell_count=cell_count+1;
                    if theCell.grew
                        sol.tp(theCell.gen) = sol.tp(theCell.gen)+1;
                        if (theCell.tdiv < 36*60 &&theCell.tdiv > 12*60) || (theCell.gen == 1 && (theCell.tdiv < 48*60 &&theCell.tdiv > 24*60))
                            sol.tp24(theCell.gen) = sol.tp24(theCell.gen) +1;
                            sol.h24counts(theCell.gen) = sol.h24counts(theCell.gen) +1;
                        end
                        sol.TdecideTimes{theCell.gen}{end+1}=theCell.tdecide;
                        sol.TdecideMothers{theCell.gen}{end+1}=theCell.parent;
                    else
                        sol.fn(theCell.gen) = sol.fn(theCell.gen)+1;
                        if theCell.tdiv < 24*60 || (theCell.gen == 1 && theCell.tdiv < 48*60)
                            sol.fn24(theCell.gen) = sol.fn24(theCell.gen) +1;
                            sol.h24counts(theCell.gen) = sol.h24counts(theCell.gen) +1;
                        end
                    end
                    sol.fs(theCell.gen)=sol.fs(theCell.gen)+1;
                    numdivs = numdivs+1;

                    sol.Tdivs(theCell.gen,ceil(theCell.tdiv/60))=sol.Tdivs(theCell.gen,ceil(theCell.tdiv/60))+1;
                    sol.divs(end+1)=ceil(theCell.tdiv/60);
                    for s=1:144
                        if size(theCell.v.OUTPUT2,1) > 100
                            for i = 1:1:100
                                sol.raverages(i,s,theCell.gen)=sol.raverages(i,s,theCell.gen)+theCell.v.OUTPUT2(ceil((size(theCell.v.OUTPUT2,1)*i)/100),s);
                            end
                        else
                            for i = 1:1:100
                                j=ceil((i*size(theCell.v.OUTPUT2,1))/100.0);
                                sol.raverages(i,s,theCell.gen)=sol.raverages(i,s,theCell.gen)+theCell.v.OUTPUT2(j,s);
                            end
                        end
                    end
                    sol.TdivTimes{theCell.gen}{end+1}=theCell.tdiv;
                    sol.TdivMothers{theCell.gen}{end+1}=theCell.parent;

                    dividers=dividers+1;
                   
                     r = 1;
                    if experiment.PARTITION_CV>0
                        r = max(0,normrnd(1,experiment.PARTITION_CV));
                    end
                    dcell.v = getDaughterCellAsym(theCell.v,vo,r);
                    dcell.x = dcell.v.SPECIES{1};
                    

                    dcell.x(62) = experiment.L;

                    dcell.x(134)=dcell.x(end,134)/2;
                    dcell.x(132)=dcell.x(end,132)/2;
                    
                    
                    dcell.x(126)=1.0;
                    for i = 3:3:21
                        dcell.x(i-1)= (dcell.x(i-1)+dcell.x(i))/2;
                        dcell.x(i)=(dcell.x(i-1)+dcell.x(i))/2;
                    end

                    for i = 23:2:61
                        dcell.x(i-1)= (dcell.x(i-1)+dcell.x(i))/2;
                        dcell.x(i)=(dcell.x(i-1)+dcell.x(i))/2;
                    end
                    dcell.birthday=theCell.tdiv+theCell.birthday;  % start at division time
                    dcell.gen = theCell.gen+1;
                    dcell.id = cell_id;
                    cell_id=cell_id+1;
                    dcell.parent = theCell.id;
                    dcell.v.SPECIES{1} = dcell.x;
                    dcell.founder= theCell.founder;
                    if numel(cells2) < N*100
                        cells2{end+1} = dcell;  % append
                    end

                    r = (1-(r-1));
                    dcell2.v = getDaughterCellAsym(theCell.v,vo,r);
                    dcell2.x = dcell2.v.SPECIES{1};
                    
    
                    dcell2.x(62) = experiment.L;

                    
                    dcell2.x(134)=dcell2.x(end,134)/2;
                    dcell2.x(132)=dcell2.x(end,132)/2;
                    dcell2.x(126) = 1.0; % set to 1 to avoid weirdness
  
                    for i = 3:3:21
                        dcell2.x(i-1)= (dcell2.x(i-1)+dcell2.x(i))/2;
                        dcell2.x(i)=(dcell2.x(i-1)+dcell2.x(i))/2;
                    end

                    for i = 23:2:61
                        dcell2.x(i-1)= (dcell2.x(i-1)+dcell2.x(i))/2;
                        dcell2.x(i)=(dcell2.x(i-1)+dcell2.x(i))/2;
                    end

                    %%% L is constant
                    dcell2.x(62) = experiment.L;
                    dcell2.birthday=theCell.tdiv+theCell.birthday;  % start at division time
                    dcell2.gen =theCell.gen+1;
                    dcell2.id = cell_id;
                    cell_id=cell_id+1;
                    dcell2.parent = theCell.id;
                    dcell2.founder= theCell.founder;
                    dcell2.v.SPECIES{1} = dcell2.x;
                    if numel(cells2) < N*100
                        cells2{end+1} = dcell2;  % append
                    end
     
                    RelA50nIndex=33;
                    cRel50nIndex=53;
                    RelA50TotalIndex=[32:41];
                    cRel50TotalIndex=[52:61];
                    RelAnIndex=[15,23:2:41];
                    cRelnIndex=[21,53:2:61];
                    RelATotalIndex=[14,15,22:41];
                    cRelTotalIndex=[20,21,52:61];
                    BclXLIndex=[61+33];
                    CYCDIndex=[61+58+3];
                    MycIndex=[61+58+24];
                    IkBaIndex=[1];
                    IkBbIndex=[4];
                    IkBeIndex=[7];
                    IkBdIndex=[10];
                    MassIndex=[61+28+15];
                    cParpIndex=[84];
                    ParpIndex=[82];
                    c3ParpIndex=[83];
                    cdh1Index=[126];
                    AIDIndex=[149];
                    IRFIndex=[145];
                    Blimp1Index=[146];
                    Bach2Index=[148];
        if totalCellNumberCurrentlyProcessed+length(cellsToProcess)>size(sol.RelA50n,2)
            sol=increaseTimeCourseLength(sol,cellsToProcess);
        end



                    ceil(theCell.birthday/30);
                    ceil(theCell.tdie/30);
                    totalCellNumberCurrentlyProcessed;
                    RelA50nIndex;
                    size(sum(theCell.v.OUTPUT2(1:30:end,RelA50nIndex),2));
                    birthday=ceil(theCell.birthday/30);
                    deathTime=ceil(theCell.tdiv/30)+birthday;
                    birthday=birthday+1;
                    
                    sol.RelA50n(birthday:deathTime,totalCellNumberCurrentlyProcessed)=sum(theCell.v.OUTPUT2(1:30:end,RelA50nIndex),2);
                    sol.cRel50n(birthday:deathTime,totalCellNumberCurrentlyProcessed)=sum(theCell.v.OUTPUT2(1:30:end,cRel50nIndex),2);
                    sol.RelA50Total(birthday:deathTime,totalCellNumberCurrentlyProcessed)=sum(theCell.v.OUTPUT2(1:30:end,RelA50TotalIndex),2);
                    sol.cRel50Total(birthday:deathTime,totalCellNumberCurrentlyProcessed)=sum(theCell.v.OUTPUT2(1:30:end,cRel50TotalIndex),2);
                    sol.RelAn(birthday:deathTime,totalCellNumberCurrentlyProcessed)=sum(theCell.v.OUTPUT2(1:30:end,RelAnIndex),2);
                    sol.cReln(birthday:deathTime,totalCellNumberCurrentlyProcessed)=sum(theCell.v.OUTPUT2(1:30:end,cRelnIndex),2);
                    sol.RelATotal(birthday:deathTime,totalCellNumberCurrentlyProcessed)=sum(theCell.v.OUTPUT2(1:30:end,RelATotalIndex),2);
                    sol.cRelTotal(birthday:deathTime,totalCellNumberCurrentlyProcessed)=sum(theCell.v.OUTPUT2(1:30:end,cRelTotalIndex),2);
                    sol.BclXL(birthday:deathTime,totalCellNumberCurrentlyProcessed)=sum(theCell.v.OUTPUT2(1:30:end,BclXLIndex),2);
                    sol.CYCD(birthday:deathTime,totalCellNumberCurrentlyProcessed)=sum(theCell.v.OUTPUT2(1:30:end,CYCDIndex),2);
                    sol.Myc(birthday:deathTime,totalCellNumberCurrentlyProcessed)=sum(theCell.v.OUTPUT2(1:30:end,MycIndex),2);
                    sol.IkBa(birthday:deathTime,totalCellNumberCurrentlyProcessed)=sum(theCell.v.OUTPUT2(1:30:end,IkBaIndex),2);
                    sol.IkBb(birthday:deathTime,totalCellNumberCurrentlyProcessed)=sum(theCell.v.OUTPUT2(1:30:end,IkBbIndex),2);
                    sol.IkBe(birthday:deathTime,totalCellNumberCurrentlyProcessed)=sum(theCell.v.OUTPUT2(1:30:end,IkBeIndex),2);
                    sol.IkBd(birthday:deathTime,totalCellNumberCurrentlyProcessed)=sum(theCell.v.OUTPUT2(1:30:end,IkBdIndex),2);
                    sol.Mass(birthday:deathTime,totalCellNumberCurrentlyProcessed)=sum(theCell.v.OUTPUT2(1:30:end,MassIndex),2);
                    sol.cParp(birthday:deathTime,totalCellNumberCurrentlyProcessed)=sum(theCell.v.OUTPUT2(1:30:end,cParpIndex),2);
                    sol.Parp(birthday:deathTime,totalCellNumberCurrentlyProcessed)=sum(theCell.v.OUTPUT2(1:30:end,ParpIndex),2);
                    sol.c3Parp(birthday:deathTime,totalCellNumberCurrentlyProcessed)=sum(theCell.v.OUTPUT2(1:30:end,c3ParpIndex),2);
                    sol.cdh1(birthday:deathTime,totalCellNumberCurrentlyProcessed)=sum(theCell.v.OUTPUT2(1:30:end,cdh1Index),2);
                    
                    
                    sol.IRF4(birthday:deathTime,totalCellNumberCurrentlyProcessed)=sum(theCell.v.OUTPUT2(1:30:end,IRFIndex),2);
                    sol.IRF4(end,totalCellNumberCurrentlyProcessed)=theCell.gen;                    
                    sol.AID(birthday:deathTime,totalCellNumberCurrentlyProcessed)=sum(theCell.v.OUTPUT2(1:30:end,AIDIndex),2);
                    sol.AID(end,totalCellNumberCurrentlyProcessed)=theCell.gen;                    
                    sol.Blimp(birthday:deathTime,totalCellNumberCurrentlyProcessed)=sum(theCell.v.OUTPUT2(1:30:end,Blimp1Index),2);
                    sol.Blimp(end,totalCellNumberCurrentlyProcessed)=theCell.gen;
                    sol.Bach2(birthday:deathTime,totalCellNumberCurrentlyProcessed)=sum(theCell.v.OUTPUT2(1:30:end,Bach2Index),2);
                    sol.Bach2(end,totalCellNumberCurrentlyProcessed)=theCell.gen;
                    
                    sol.cParp(end,totalCellNumberCurrentlyProcessed)=theCell.gen;
                    sol.Parp(end,totalCellNumberCurrentlyProcessed)=theCell.gen;
                    sol.c3Parp(end,totalCellNumberCurrentlyProcessed)=theCell.gen;
                    sol.cdh1(end,totalCellNumberCurrentlyProcessed)=theCell.gen;
                    
                    sol.RelA50n(end,totalCellNumberCurrentlyProcessed)=theCell.gen;
                    sol.cRel50n(end,totalCellNumberCurrentlyProcessed)=theCell.gen;
                    sol.RelA50Total(end,totalCellNumberCurrentlyProcessed)=theCell.gen;
                    sol.cRel50Total(end,totalCellNumberCurrentlyProcessed)=theCell.gen;
                    sol.RelAn(end,totalCellNumberCurrentlyProcessed)=theCell.gen;
                    sol.cReln(end,totalCellNumberCurrentlyProcessed)=theCell.gen;
                    sol.RelATotal(end,totalCellNumberCurrentlyProcessed)=theCell.gen;
                    sol.cRelTotal(end,totalCellNumberCurrentlyProcessed)=theCell.gen;
                    sol.BclXL(end,totalCellNumberCurrentlyProcessed)=theCell.gen;
                    sol.CYCD(end,totalCellNumberCurrentlyProcessed)=theCell.gen;
                    sol.Myc(end,totalCellNumberCurrentlyProcessed)=theCell.gen;
                    sol.IkBa(end,totalCellNumberCurrentlyProcessed)=theCell.gen;
                    sol.IkBb(end,totalCellNumberCurrentlyProcessed)=theCell.gen;
                    sol.IkBe(end,totalCellNumberCurrentlyProcessed)=theCell.gen;
                    sol.IkBd(end,totalCellNumberCurrentlyProcessed)=theCell.gen;
                    sol.Mass(end,totalCellNumberCurrentlyProcessed)=theCell.gen;
                    
                    
                    
                    sol.lineageInfo(1,totalCellNumberCurrentlyProcessed)= theCell.id;
                    sol.lineageInfo(2,totalCellNumberCurrentlyProcessed)=theCell.parent;
                    sol.lineageInfo(3,totalCellNumberCurrentlyProcessed)=theCell.birthday+theCell.tdiv;
                    sol.lineageInfo(4, totalCellNumberCurrentlyProcessed)= theCell.tAIDUp;
                    sol.lineageInfo(5, totalCellNumberCurrentlyProcessed)= theCell.tAIDDown;
                    sol.lineageInfo(6, totalCellNumberCurrentlyProcessed)= theCell.tBlimpUp;
                    
                    totalCellNumberCurrentlyProcessed=totalCellNumberCurrentlyProcessed+1;
                    cells(1)=[];
                end
            end
            sol.divbag{end+1}=sol.divs;
            sol.diebag{end+1}=sol.deaths;
            sol.decidebag{end+1}=sol.decides;
            for s=1:144
                for i=1:100
                    sol.qaverages(i,s,Cgen)=sol.qaverages(i,s,Cgen)/nondividers;
                    sol.raverages(i,s,Cgen)=sol.raverages(i,s,Cgen)/dividers;
                end
            end

            if length(cells2)<1
            elseif length(cells2)<150
                experiment_label_Cells=sprintf('Cells-%s.mat',datestr(now,'mmmm dd, yyyy HH-MM-SS-FFF'));
                fileToSave=fullfile('unprocessedCells',experiment_label_Cells);
                cells=cells2;
                save('-v7.3',fileToSave,'cells');
            else
                numberOfFiles=0;
                for cellIndex=1:150:length(cells2)
                    experiment_label_Cells=sprintf('Cells-%s.mat',datestr(now,'mmmm dd, yyyy HH-MM-SS-FFF'));
                    fileToSave=fullfile('unprocessedCells',experiment_label_Cells);
                    indexToSaveFrom=cellIndex;
                    indexToSaveTo=cellIndex+149;
                    if length(cells2)<indexToSaveTo
                        indexToSaveTo=length(cells2);
                    end
                    variableToSave=cells2(indexToSaveFrom:indexToSaveTo);
                    cells=variableToSave;
                    save('-v7.3',fileToSave,'cells');
                    numberOfFiles=numberOfFiles+1;
                end
            end
                     
            if totalCellNumberCurrentlyProcessed+length(cellsToProcess)>size(sol.RelA50n,2)
                sol=increaseTimeCourseLength(sol,cellsToProcess);
            end
            
            fileToSave=fullfile('Checkpoints', 'solutionOut.mat');
            save('-v7.3',fileToSave,'sol');

            movefile(fullfile('unprocessedCells',cellsToProcess(k).name),fullfile('processedCells',cellsToProcess(k).name));
            

            
        end
    end
        
    
    sol.RelA50n( :, ~any(sol.RelA50n,1) ) = [];
    sol.cRel50n( :, ~any(sol.cRel50n,1) ) = [];
    sol.RelA50Total( :, ~any(sol.RelA50Total,1) ) = [];
    sol.cRel50Total( :, ~any(sol.cRel50Total,1) ) = [];
    sol.RelAn( :, ~any(sol.RelAn,1) ) = [];
    sol.cReln( :, ~any(sol.cReln,1) ) = [];
    sol.RelATotal( :, ~any(sol.RelATotal,1) ) = [];
    sol.cRelTotal( :, ~any(sol.cRelTotal,1) ) = [];
    sol.BclXL( :, ~any(sol.BclXL,1) ) = [];
    sol.CYCD( :, ~any(sol.CYCD,1) ) = [];
    sol.Myc( :, ~any(sol.Myc,1) ) = [];
    sol.IkBa( :, ~any(sol.IkBa,1) ) = [];
    sol.IkBb( :, ~any(sol.IkBb,1) ) = [];
    sol.IkBe( :, ~any(sol.IkBe,1) ) = [];
    sol.IkBd( :, ~any(sol.IkBd,1) ) = [];
    sol.Mass( :, ~any(sol.Mass,1) ) = [];
    sol.cParp(:, ~any(sol.cParp,1) ) = [];
    sol.Parp(:, ~any(sol.Parp,1) ) = [];
    sol.c3Parp(:, ~any(sol.c3Parp,1) ) = [];
    sol.cdh1(:, ~any(sol.cdh1,1) ) = [];
    sol.IRF4(:, ~any(sol.IRF4,1) ) = [];
    sol.AID(:, ~any(sol.AID,1) ) = [];
    sol.Blimp(:, ~any(sol.Blimp,1) ) = [];
    sol.Bach2(:, ~any(sol.Bach2,1) ) = [];

    
    sol.lineageInfo( :, ~any(sol.lineageInfo,1) ) = [];
    
    for i=1:maxGens
        sol.counts(:,i)=sol.counts(:,i)-1;
    end
    accuracies=zeros(maxGens,1);
    logErrors=zeros(maxGens,2);
    statistics=zeros(maxGens,20);
    for g=1:maxGens
        if sol.integralCounts(g) > 0
            sol.fs(g)=sol.fs(g)/sol.integralCounts(g);
            sol.gs(g)=sol.gs(g)/sol.integralCounts(g);
            sol.tp(g)=sol.tp(g)/sol.integralCounts(g);
            sol.tn(g)=sol.tn(g)/sol.integralCounts(g);
            sol.fp(g)=sol.fp(g)/sol.integralCounts(g);
            sol.fn(g)=sol.fn(g)/sol.integralCounts(g);
            sol.tp24(g)=sol.tp24(g)/sol.h24counts(g);
            sol.tn24(g)=sol.tn24(g)/sol.h24counts(g);
            sol.fp24(g)=sol.fp24(g)/sol.h24counts(g);
            sol.fn24(g)=sol.fn24(g)/sol.h24counts(g);
            statistics(g,1)=sol.integralCounts(g);
            statistics(g,2)=sol.gs(g);
            statistics(g,3)=sol.fs(g);
            statistics(g,4)=sol.tp(g);
            statistics(g,5)=sol.tn(g);
            statistics(g,6)=sol.fp(g);
            statistics(g,7)=sol.fn(g);
            accuracies(g)=(sol.tp(g)+sol.tn(g));
            statistics(g,8)=accuracies(g);
            if ~ isempty(sol.divbag{g})
                sol.maxDivGen=g;
                vector = sol.divbag{g};
                [parmhat,parmci] = lognfit(vector(:));
                [M,V]=lognstat(parmhat(1),parmhat(2));
                TdivFits(g,1)=M;
                TdivFits(g,2)=sqrt(V);
                [Mlo,Vlo]=lognstat(parmci(1,1),parmci(2,2));
                [Mhi,Vhi]=lognstat(parmci(1,2),parmci(2,1));
                TdivFits(g,3)=Mlo;
                TdivFits(g,4)=Mhi;
                TdivFits(g,5)=sqrt(Vlo);
                TdivFits(g,6)=sqrt(Vhi);
                logErrors(g,1)=(((Mhi-Mlo)/M)+((Vhi-Vlo)/V))/2;
                for i = 1:6
                    statistics(g,8+i)=TdivFits(g,i);
                end
            end
            if ~ isempty(sol.diebag{g}) 
                sol.maxDieGen=g;
                vector = sol.diebag{g};
                [parmhat,parmci] = lognfit(vector(:));
                [M,V]=lognstat(parmhat(1),parmhat(2));
                TdieFits(g,1)=M;
                TdieFits(g,2)=sqrt(V);
                [Mlo,Vlo]=lognstat(parmci(1,1),parmci(2,2));
                [Mhi,Vhi]=lognstat(parmci(1,2),parmci(2,1));
                TdieFits(g,3)=Mlo;
                TdieFits(g,4)=Mhi;
                TdieFits(g,5)=sqrt(Vlo);
                TdieFits(g,6)=sqrt(Vhi);
                logErrors(g,2)=(((Mhi-Mlo)/M)+((Vhi-Vlo)/V))/2;
                for i = 1:6
                    statistics(g,14+i)=TdieFits(g,i);
                end
            end
        end    
    end
    sol.statistics = statistics;
    sol.logErrors = logErrors;
    sol.TdivFits = TdivFits;
    sol.TdieFits = TdieFits;   
end

function saveSolutions(solutions,N,maxTime,maxGens,label,paramString)
    experiment_label=sprintf('%s %s',label,datestr(now,'mmmm dd, yyyy HH-MM-SS-FFF'));
    mkdir(experiment_label);
    copyfile('*.m',experiment_label);
    ts = 1:30:maxTime;
    ts=ts./60;
    totals = zeros(length(solutions),length(ts));
    for r = 1:length(solutions)
        for t = 1:length(ts)
            totals(r,t) = sum(solutions{r}.counts(t,:));
        end
    end
    handle = fopen(sprintf('%s\\Parameters.txt',experiment_label),'w+');
    fprintf(handle,paramString);
    fclose(handle);
    outarray = zeros((length(solutions)+1)*(maxGens+1)+1,length(ts));
    outarray(1,:) = ts';
    for g = 1: maxGens
       means = zeros(length(ts),1);
       for r = 1: length(solutions)
            means=means+solutions{r}.counts(:,g);
       end
       outarray(g+1,:)=means(:)./length(solutions);
    end
    outarray(maxGens+2,:)=sum(outarray(2:g+1,:));
    for r = 1: length(solutions)
        for g = 1: maxGens
            outarray((r)*(maxGens+1)+g+1,:)=solutions{r}.counts(:,g);
        end
        outarray((r)*(maxGens+1)+maxGens+2,:)=totals(r,:);
    end
    csvwrite(sprintf('%s\\counts.csv',experiment_label),outarray');

    outarray = zeros(length(solutions)*maxGens*2,100);
    for r= 1: length(solutions)
        for g=1:maxGens
            outarray((r-1)*maxGens*2+g,:)=solutions{r}.qaverages(:,134,g);
        end
    end
    for r= 1: length(solutions)
        for g=1:maxGens
            outarray((r-1)*maxGens*2+g+maxGens,:)=solutions{r}.raverages(:,134,g);
        end
    end
    csvwrite(sprintf('%s\\Masses.csv',experiment_label),outarray');
    for r= 1: length(solutions)
        for g=1:maxGens
            outarray((r-1)*maxGens*2+g,:)=solutions{r}.qaverages(:,33,g);
        end
    end
    for r= 1: length(solutions)
        for g=1:maxGens
            outarray((r-1)*maxGens*2+g+maxGens,:)=solutions{r}.raverages(:,33,g);
        end
    end
    csvwrite(sprintf('%s\\RelA50n.csv',experiment_label),outarray');   
    for r= 1: length(solutions)
        for g=1:maxGens
            outarray((r-1)*maxGens*2+g,:)=solutions{r}.qaverages(:,53,g);
        end
    end
    for r= 1: length(solutions)
        for g=1:maxGens
            outarray((r-1)*maxGens*2+g+maxGens,:)=solutions{r}.raverages(:,53,g);
        end
    end
    csvwrite(sprintf('%s\\cRel50n.csv',experiment_label),outarray'); 
    for r= 1: length(solutions)
        for g=1:maxGens
            outarray((r-1)*maxGens*2+g,:)=solutions{r}.qaverages(:,94,g);
        end
    end
    for r= 1: length(solutions)
        for g=1:maxGens
            outarray((r-1)*maxGens*2+g+maxGens,:)=solutions{r}.raverages(:,94,g);
        end
    end
    csvwrite(sprintf('%s\\BclXL.csv',experiment_label),outarray'); 
    for r= 1: length(solutions)
        for g=1:maxGens
            outarray((r-1)*maxGens*2+g,:)=solutions{r}.qaverages(:,143,g);
        end
    end
    for r= 1: length(solutions)
        for g=1:maxGens
            outarray((r-1)*maxGens*2+g+maxGens,:)=solutions{r}.raverages(:,143,g);
        end
    end
    csvwrite(sprintf('%s\\Myc.csv',experiment_label),outarray'); 
    for r= 1: length(solutions)
        for g=1:maxGens
            outarray((r-1)*maxGens*2+g,:)=solutions{r}.qaverages(:,122,g);
        end
    end
    for r= 1: length(solutions)
        for g=1:maxGens
            outarray((r-1)*maxGens*2+g+maxGens,:)=solutions{r}.raverages(:,122,g);
        end
    end
    csvwrite(sprintf('%s\\CYCD.csv',experiment_label),outarray'); 
    
    

    mkdir(fullfile(experiment_label,'MetaboliteTimeCourses'));
    
    for r= 1: length(solutions)   
        
        csvwrite(fullfile(experiment_label,'MetaboliteTimeCourses',strcat('RelA50n-rep',num2str(r),'.CSV')),solutions{r}.RelA50n);
        csvwrite(fullfile(experiment_label,'MetaboliteTimeCourses',strcat('cRel50n-rep',num2str(r),'.CSV')),solutions{r}.cRel50n);
        csvwrite(fullfile(experiment_label,'MetaboliteTimeCourses',strcat('RelA50Total-rep',num2str(r),'.CSV')),solutions{r}.RelA50Total);
        csvwrite(fullfile(experiment_label,'MetaboliteTimeCourses',strcat('cRel50Total-rep',num2str(r),'.CSV')),solutions{r}.cRel50Total);
        csvwrite(fullfile(experiment_label,'MetaboliteTimeCourses',strcat('RelAn-rep',num2str(r),'.CSV')),solutions{r}.RelAn);
        csvwrite(fullfile(experiment_label,'MetaboliteTimeCourses',strcat('cReln-rep',num2str(r),'.CSV')),solutions{r}.cReln);
        csvwrite(fullfile(experiment_label,'MetaboliteTimeCourses',strcat('RelATotal-rep',num2str(r),'.CSV')),solutions{r}.RelATotal);
        csvwrite(fullfile(experiment_label,'MetaboliteTimeCourses',strcat('cRelTotal-rep',num2str(r),'.CSV')),solutions{r}.cRelTotal);
        csvwrite(fullfile(experiment_label,'MetaboliteTimeCourses',strcat('BclXL-rep',num2str(r),'.CSV')),solutions{r}.BclXL);
        csvwrite(fullfile(experiment_label,'MetaboliteTimeCourses',strcat('CYCD-rep',num2str(r),'.CSV')),solutions{r}.CYCD);
        csvwrite(fullfile(experiment_label,'MetaboliteTimeCourses',strcat('Myc-rep',num2str(r),'.CSV')),solutions{r}.Myc);
        csvwrite(fullfile(experiment_label,'MetaboliteTimeCourses',strcat('IkBa-rep',num2str(r),'.CSV')),solutions{r}.IkBa);
        csvwrite(fullfile(experiment_label,'MetaboliteTimeCourses',strcat('IkBb-rep',num2str(r),'.CSV')),solutions{r}.IkBb);
        csvwrite(fullfile(experiment_label,'MetaboliteTimeCourses',strcat('IkBe-rep',num2str(r),'.CSV')),solutions{r}.IkBe);
        csvwrite(fullfile(experiment_label,'MetaboliteTimeCourses',strcat('IkBd-rep',num2str(r),'.CSV')),solutions{r}.IkBd);
        csvwrite(fullfile(experiment_label,'MetaboliteTimeCourses',strcat('Mass-rep',num2str(r),'.CSV')),solutions{r}.Mass);
        csvwrite(fullfile(experiment_label,'MetaboliteTimeCourses',strcat('cParp-rep',num2str(r),'.CSV')),solutions{r}.cParp);        
        csvwrite(fullfile(experiment_label,'MetaboliteTimeCourses',strcat('Parp-rep',num2str(r),'.CSV')),solutions{r}.Parp);        
        csvwrite(fullfile(experiment_label,'MetaboliteTimeCourses',strcat('c3Parp-rep',num2str(r),'.CSV')),solutions{r}.c3Parp);        
        csvwrite(fullfile(experiment_label,'MetaboliteTimeCourses',strcat('cdh1-rep',num2str(r),'.CSV')),solutions{r}.cdh1);        
        csvwrite(fullfile(experiment_label,'MetaboliteTimeCourses',strcat('IRF4-rep',num2str(r),'.CSV')),solutions{r}.IRF4);        
        csvwrite(fullfile(experiment_label,'MetaboliteTimeCourses',strcat('AID-rep',num2str(r),'.CSV')),solutions{r}.AID);        
        csvwrite(fullfile(experiment_label,'MetaboliteTimeCourses',strcat('Blimp-rep',num2str(r),'.CSV')),solutions{r}.Blimp);        
        csvwrite(fullfile(experiment_label,'MetaboliteTimeCourses',strcat('Bach2-rep',num2str(r),'.CSV')),solutions{r}.Bach2);        
        

        
        csvwrite(fullfile(experiment_label,'MetaboliteTimeCourses',strcat('lineageInfo-rep',num2str(r),'.CSV')),solutions{r}.lineageInfo);
        csvwrite(fullfile(experiment_label,'MetaboliteTimeCourses',strcat('generationOverTime-rep',num2str(r),'.CSV')),solutions{r}.generationsOverTime);
        csvwrite(fullfile(experiment_label,'MetaboliteTimeCourses',strcat('rangeDistribution-rep',num2str(r),'.CSV')),solutions{r}.rangeDistribution);

        csvwrite(fullfile(experiment_label,'MetaboliteTimeCourses',strcat('maxGenDistribution-rep',num2str(r),'.CSV')),solutions{r}.maxGenDistribution);
        csvwrite(fullfile(experiment_label,'MetaboliteTimeCourses',strcat('minGenDistribution-rep',num2str(r),'.CSV')),solutions{r}.minGenDistribution);


    end
    
    
    
    outarray = zeros(maxGens,(length(solutions)+1)*9);
    for r = 1: length(solutions)
        for g = 1: maxGens
            outarray(g,(r)*9+1)=solutions{r}.fs(g);
            outarray(g,(r)*9+2)=solutions{r}.tp(g);
            outarray(g,(r)*9+3)=solutions{r}.fp(g);
            outarray(g,(r)*9+4)=solutions{r}.tn(g);
            outarray(g,(r)*9+5)=solutions{r}.fn(g);
            outarray(g,(r)*9+6)=solutions{r}.tp24(g);
            outarray(g,(r)*9+7)=solutions{r}.fp24(g);
            outarray(g,(r)*9+8)=solutions{r}.tn24(g);
            outarray(g,(r)*9+9)=solutions{r}.fn24(g);
            outarray(g, 1)=outarray(g, 1)+solutions{r}.fs(g)/length(solutions);
            outarray(g, 2)=outarray(g, 2)+solutions{r}.tp24(g)/length(solutions);
            outarray(g, 3)=outarray(g, 3)+solutions{r}.fp24(g)/length(solutions);
            outarray(g, 4)=outarray(g, 4)+solutions{r}.tn24(g)/length(solutions);
            outarray(g, 5)=outarray(g, 5)+solutions{r}.fn24(g)/length(solutions);
            outarray(g, 6)=outarray(g, 6)+(solutions{r}.tp24(g)/(solutions{r}.tp24(g)+solutions{r}.fp24(g)))/length(solutions);
            outarray(g, 7)=outarray(g, 7)+(solutions{r}.fp24(g)/(solutions{r}.tp24(g)+solutions{r}.fp24(g)))/length(solutions);
            outarray(g, 8)=outarray(g, 8)+(solutions{r}.tn24(g)/(solutions{r}.tn24(g)+solutions{r}.fn24(g)))/length(solutions);
            outarray(g, 9)=outarray(g, 9)+(solutions{r}.fn24(g)/(solutions{r}.tn24(g)+solutions{r}.fn24(g)))/length(solutions);

        end
    end
    csvwrite(sprintf('%s\\Fs.csv',experiment_label),outarray);    
    handle = fopen(sprintf('%s\\FateTimes.csv',experiment_label),'w+');
    for r = 1:length(solutions)
        for g = 1:maxGens
            fprintf(handle,',,%dTdec%d,,%dTdiv%d,,%dTdie%d',r,g,r,g,r,g);
        end
    end
    fprintf(handle,',AllTdec0,AllTdiv0,AllTdie0,AllTdec1+,AllTdiv1+,AllTdie1+\n');
    AllTdec0 = cell(1);
    AllTdiv0 = cell(1);
    AllTdie0 = cell(1);
    AllTdec1 = cell(1);
    AllTdiv1 = cell(1);
    AllTdie1 = cell(1);
    for r = 1: length(solutions)
        for t = 1:numel(solutions{r}.TdecideTimes{1})
            if numel(solutions{r}.TdecideTimes{1}{1}) > 0
                AllTdec0{end+1} = solutions{r}.TdecideTimes{1}{t};
            end
        end
        for t = 1:numel(solutions{r}.TdivTimes{1})
            if numel(solutions{r}.TdivTimes{1}{1}) > 0
                AllTdiv0{end+1} = solutions{r}.TdivTimes{1}{t};
            end
        end
        for t = 1:numel(solutions{r}.TdieTimes{1})
            if numel(solutions{r}.TdieTimes{1}{1}) > 0
                AllTdie0{end+1} = solutions{r}.TdieTimes{1}{t};
            end
        end

        for g = 2:maxGens
            for t = 1:numel(solutions{r}.TdecideTimes{g})
                if numel(solutions{r}.TdecideTimes{g}{t}) > 0
                    AllTdec1{end+1} = solutions{r}.TdecideTimes{g}{t};
                end
            end
            for t = 1:numel(solutions{r}.TdivTimes{g})
                if numel(solutions{r}.TdivTimes{g}{t}) > 0
                    AllTdiv1{end+1} = solutions{r}.TdivTimes{g}{t};
                end
            end
            for t = 1:numel(solutions{r}.TdieTimes{g})
                if numel(solutions{r}.TdieTimes{g}{t}) > 0
                    AllTdie1{end+1} = solutions{r}.TdieTimes{g}{t};
                end
            end
        end
    end
    for row = 1:100000
       rowcount=0;
       for r = 1: length(solutions)
            for i = 1:maxGens
                if row <= numel(solutions{r}.TdecideTimes{i}) 
                   fprintf(handle,',%d,%2.2f',solutions{r}.TdecideMothers{i}{row},solutions{r}.TdecideTimes{i}{row}/60.0);
                   rowcount=rowcount+1;
                else
                    fprintf(handle,',,');
                end
                if row <= numel(solutions{r}.TdivTimes{i})
                   fprintf(handle,',%d,%2.2f',solutions{r}.TdivMothers{i}{row},solutions{r}.TdivTimes{i}{row}/60.0);
                   rowcount=rowcount+1;
                else
                    fprintf(handle,',,');
                end
                if row <= numel(solutions{r}.TdieTimes{i})
                   fprintf(handle,',%d,%2.2f',solutions{r}.TdieMothers{i}{row},solutions{r}.TdieTimes{i}{row}/60.0);
                   rowcount=rowcount+1;
                else
                    fprintf(handle,',,');
                end
            end
       end
       if row <= numel(AllTdec0)
           fprintf(handle,',%2.2f',AllTdec0{row}/60.0);
           rowcount=rowcount+1;
       else
           fprintf(handle,',');
       end
       if row <= numel(AllTdiv0)
           fprintf(handle,',%2.2f',AllTdiv0{row}/60.0);
           rowcount=rowcount+1;
       else
           fprintf(handle,',');
       end
       if row <= numel(AllTdie0)
           fprintf(handle,',%2.2f',AllTdie0{row}/60.0);
           rowcount=rowcount+1;
       else
           fprintf(handle,',');
       end
       if row <= numel(AllTdec1)
           fprintf(handle,',%2.2f',AllTdec1{row}/60.0);
           rowcount=rowcount+1;
       else
           fprintf(handle,',');
       end
       if row <= numel(AllTdiv1)
           fprintf(handle,',%2.2f',AllTdiv1{row}/60.0);
           rowcount=rowcount+1;
       else
           fprintf(handle,',');
       end
       if row <= numel(AllTdie1)
           fprintf(handle,',%2.2f',AllTdie1{row}/60.0);
           rowcount=rowcount+1;
       else
           fprintf(handle,',');
       end

       fprintf(handle,'\n');
       if rowcount == 0
           break;
       end
    end
    fclose(handle);

end


function new = copy(this)
    new = feval(class(this));
    p = fieldnames(struct(this));
    for i = 1:length(p)
        new.(p{i}) = this.(p{i});
    end
end

function c2 = duplicate(sol)
    c2 = struct;   
    c2.NFKB_CYCD_T=sol.NFKB_CYCD_T;
    c2.NFKB_BCL2_T=sol.NFKB_BCL2_T;
    c2.NFKB_MYC_T=sol.NFKB_MYC_T;
    c2.GROWTH_T=sol.GROWTH_T;
    c2.RATE_CV=sol.RATE_CV;
    c2.CONC_CV=sol.CONC_CV;
    c2.PARTITION_CV=sol.PARTITION_CV;
    c2.VOL_CV=sol.VOL_CV;
    c2.IKK_CV=sol.IKK_CV;
    c2.GMSyn=sol.GMSyn;
    c2.GMDeg=sol.GMDeg;
    c2.MassGrowth=sol.MassGrowth;
    c2.MassDecay=sol.MassDecay;
    c2.CYCDtSyn=    sol.CYCDtSyn;
    c2.CYCDtDeg=    sol.CYCDtDeg;
    c2.BCL2tSyn=    sol.BCL2tSyn;
    c2.BCL2tDeg=	sol.BCL2tDeg;
    c2.MYCSyn=      sol.MYCSyn;
    c2.MYCDeg=      sol.MYCDeg;
    c2.MYCtSyn=     sol.MYCtSyn;
    c2.MYCtDeg=     sol.MYCtDeg;
    c2.L=           sol.L;
    c2.STIMULUS=    sol.STIMULUS;
    c2.CREL=        sol.CREL;
    c2.cRelFeedback=sol.cRelFeedback;
    c2.EPS=         sol.EPS;
    c2.TOTAL_IKK=   sol.TOTAL_IKK;
    c2.pre_RATE_CV = sol.pre_RATE_CV;
    c2.pre_CONC_CV = sol.pre_CONC_CV;
    c2.maxTime=sol.maxTime;  
end



function v = getRandomCell(v)
        for i = [1,2,3,4,5,11,12,13,14]          
            for j = 1:size(v.pi(i,:),2)
                v.pi(i,j)=max(0,normrnd(v.pi(i,j),v.pi(i,j)*v.pre_RATE_CV));
            end
        end
        for i = [1,2,3,4,5]         
            for j = 1:size(v.pm(i,:),2)
                v.pm(i,j)=max(0,normrnd(v.pm(i,j),v.pm(i,j)*v.pre_RATE_CV));
            end
        end
        for i = 9:12          
            for j = 1:size(v.pd(i,:),2)
                v.pd(i,j)=max(0,normrnd(v.pd(i,j),v.pd(i,j)*v.pre_RATE_CV));
            end
        end
        for i = 71:115
            v.k(i)= max(0,normrnd(v.k(i),v.k(i)*v.pre_RATE_CV));
        end
        v.k2(80)=max(0,normrnd(v.k2(80),v.k2(80)*v.pre_RATE_CV));
        v.k2(81)=max(0,normrnd(v.k2(81),v.k2(81)*v.pre_RATE_CV));                

         for i = [8,9,12:15,18:34,47:67,74:76,78:79,82:86]
             v.k2(i)= max(0,normrnd(v.k2(i),v.k2(i)*v.pre_RATE_CV));
         end
         for i = size(v.kASC,1)
            v.kASC(i,5)= max(0,normrnd(v.kASC(i,5),v.kASC(i,5)*v.pre_RATE_CV));
            v.kASC(i,8)= max(0,normrnd(v.kASC(i,8),v.kASC(i,8)*v.pre_RATE_CV));
        end
        theMask = zeros(size(v.SPECIES{1},1),1);
        theMask(137:142) = 1;
        v.SPECIES{1} = getRandomSpeciesMaskLognormal(v.SPECIES{1},theMask,v.pre_CONC_CV,0);
end


function v2 = getDaughterCell(v,vo,r)
        v2 = copy(v);
        for i = [1,2,3,4,5,11,12,13,14]          
            for j = 1:size(v.pi(i,:),2)
                v2.pi(i,j)=max(0,(normrnd(v.pi(i,j),v.pi(i,j)*v.RATE_CV)+normrnd(vo.pi(i,j),vo.pi(i,j)*vo.RATE_CV))/2);
            end
        end
        for i = [1,2,3,4,5]         
            for j = 1:size(v.pm(i,:),2)
                v2.pm(i,j)=max(0,(normrnd(v.pm(i,j),v.pm(i,j)*v.RATE_CV)+normrnd(vo.pm(i,j),vo.pm(i,j)*vo.RATE_CV))/2);
            end
        end
        for i = 9:12          
            for j = 1:size(v.pd(i,:),2)
                v2.pd(i,j)=max(0,(normrnd(v.pd(i,j),v.pd(i,j)*v.RATE_CV)+normrnd(vo.pd(i,j),vo.pd(i,j)*vo.RATE_CV))/2);
            end
        end
        for i = 71:115
            v2.k(i,j)=max(0,(normrnd(v.k(i),v.k(i)*v.RATE_CV)+normrnd(vo.k(i),vo.k(i)*vo.RATE_CV))/2);
        end
        for i = [8,9,12:15,18:34,47:67,74:76,78:86]
            v2.k2(i,j)=max(0,(normrnd(v.k2(i),v.k2(i)*v.RATE_CV)+normrnd(vo.k2(i),vo.k2(i)*vo.RATE_CV))/2);
        end
        v2.SPECIES{1}(132)=v.SPECIES{1}(132)*r;
        v2.SPECIES{1}(134)=v.SPECIES{1}(134)*r;
        if vo.IKK_CV > 0
            sigma= sqrt(log(1+(vo.IKK_CV^2)));
            mu= log(140)-0.5*sigma^2; 
            rnd = lognrnd(mu,sigma);
            v2.TOTAL_IKK=(v.TOTAL_IKK+rnd)/2;
        end

        theMask = zeros(size(v2.SPECIES{1},2),1);
        theMask(137:142) = 1;
        v2.SPECIES{1} = getRandomSpeciesMaskLognormal(v2.SPECIES{1},theMask,v.CONC_CV,0);
end

function v2 = getDaughterCellAsym(v,vo,r)
        v2 = copy(v);
        for i = [1,2,3,4,5,11,12,13,14]          
            for j = 1:size(v.pi(i,:),2)
                v2.pi(i,j)=max(0,(normrnd(v.pi(i,j),v.pi(i,j)*v.RATE_CV)));
            end
        end
        for i = [1,2,3,4,5]         
            for j = 1:size(v.pm(i,:),2)
                v2.pm(i,j)=max(0,(normrnd(v.pm(i,j),v.pm(i,j)*v.RATE_CV)));
            end
        end
        for i = 9:12          
            for j = 1:size(v.pd(i,:),2)
                v2.pd(i,j)=max(0,(normrnd(v.pd(i,j),v.pd(i,j)*v.RATE_CV)));
            end
        end
        for i = 71:115
            v2.k(i,j)=max(0,(normrnd(v.k(i),v.k(i)*v.RATE_CV)));
        end
        for i = [8,9,12:15,18:34,47:67,74:76,78:86]
            v2.k2(i,j)=max(0,(normrnd(v.k2(i),v.k2(i)*v.RATE_CV)));
        end
        for i = size(v2.kASC,1)
            v2.kASC(i,5)= max(0,normrnd(v2.kASC(i,5),v2.kASC(i,5)*v.RATE_CV));
            v2.kASC(i,8)= max(0,normrnd(v2.kASC(i,8),v2.kASC(i,8)*v.RATE_CV));
        end
        v2.SPECIES{1}(:)=v.SPECIES{1}(:).*r;

        if vo.IKK_CV > 0
            sigma= sqrt(log(1+(vo.IKK_CV^2)));
            mu= log(140)-0.5*sigma^2; 
            rnd = lognrnd(mu,sigma);
            v2.TOTAL_IKK=(v.TOTAL_IKK+rnd)/2;
        end

end

function c2= randomCondition(maxTime,parameters)
    c2 = struct;
    c2.NFKB_CYCD_T= parameters(1);
    c2.NFKB_BCL2_T= parameters(2);
    c2.NFKB_MYC_T=  parameters(3);
    c2.GROWTH_T=    parameters(4);
    c2.RATE_CV=     parameters(5);
    c2.CONC_CV=     parameters(6);
    c2.PARTITION_CV=parameters(7);
    c2.VOL_CV=      parameters(8);
    c2.IKK_CV=      parameters(9);
    c2.GMSyn=       parameters(10);
    c2.GMDeg=       parameters(11);
    c2.MassGrowth=  parameters(12);
    c2.MassDecay=   parameters(13);
    c2.CYCDtSyn=    parameters(14);
    c2.CYCDtDeg=    parameters(15);
    c2.BCL2tSyn=    parameters(16);
    c2.BCL2tDeg=	parameters(17);
    c2.MYCSyn=      parameters(18);
    c2.MYCDeg=      parameters(19);
    c2.MYCtSyn=     parameters(20);
    c2.MYCtDeg=     parameters(21);
    c2.L=           parameters(22);
    c2.STIMULUS=    parameters(23);
    c2.CREL=        parameters(24);
    c2.cRelFeedback=parameters(25);
    c2.EPS=         parameters(26);
    c2.TOTAL_IKK   =parameters(27);
    c2.pre_RATE_CV  =parameters(28);
    c2.pre_CONC_CV = parameters(29);
    c2.maxTime=maxTime;
    c2.AIDThreshold=parameters(30);
    c2.BLIMP1Threshold=parameters(31);
end


function [kinit]=getRandomRatesMaskNormal(k0,mask,CV)
    kinit = zeros(length(k0),1);
    for cc=1:length(k0)
        factor = 1;
        if mask(cc) == 1
            factor = normrnd(1,double(sqrt(CV)));
        end
        kinit(cc)=factor*k0(cc);
    end
end

function [x0aa]= getRandomSpeciesMaskLognormal(x0,mask,CV,GaussianNoise)
    x0aa = zeros(length(x0),1);
    for cc=1:length(x0)
        factor = 1;
        if GaussianNoise > 0
            factor = normrnd(1,double(GaussianNoise));
        end
        if CV >0
            sigma = sqrt(log(CV*CV+1));
        else
            sigma = 0;
        end
        mu= log(max(0,x0(cc))); 
        if mask(cc) == 1
            rnd = lognrnd(mu,sigma);
            if mu==0 
                rnd=0;
            end
            x0aa(cc)=rnd*factor;
         
        else
            x0aa(cc)=x0(cc)*factor;
        end
    end
end


