%       Runs until the first division/death event (first run also
%       equilibrates).
%       set v.PHASE to 1 to ensure that equilibration occurs before
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function v = run_cell(v,maxGen)
        %--- Call the ODE function to reset persistent variables
        nfkbDivDeath_ode_cRel([],[],[],v);
        if ~maxGen
            options=odeset('AbsTol',1E-5,'RelTol',1E-3,'Events',@divisionOrDeath);
        else
            options=odeset('AbsTol',1E-5,'RelTol',1E-3,'Events',@death);
        end
        %--- Stimulation Phase
        if v.PHASE == 2
            v.SPECIES{1}(v.SPECIES{1}<1e-7) = 0;
            initial=v.SPECIES{1};
            lastwarn('');
            [t,x,te,ye,ie]=ode15s(@(t,x) nfkbDivDeath_ode_cRel(t,x,[],v), [0 v.SIM_TIME], v.SPECIES{1},options);
            %[t,x,te,ye,ie]=ode45(@(t,x) nfkbDivDeath_ode_cRel(t,x,[],v), [0 v.SIM_TIME], v.SPECIES{1},options);
            [warnmsg, msgid] = lastwarn;
            if ~isempty(strfind(warnmsg,'singular'))||~isempty(strfind(warnmsg,'integration'))
                fprintf('A singular matrix was found due to ode15s error')
                mkdir 'errorInfo';
                csvwrite(fullfile('errorInfo',strcat('error-',(msgid),'-initial.csv')),initial);
                csvwrite(fullfile('errorInfo',strcat('error-',(msgid),'-xo.csv')),x);
                csvwrite(fullfile('errorInfo',strcat('error-',(msgid),'-t.csv')),t);
                csvwrite(fullfile('errorInfo',strcat('error-',(msgid),'-t.csv')),te);
                csvwrite(fullfile('errorInfo',strcat('error-',(msgid),'-t.csv')),ye);
                csvwrite(fullfile('errorInfo',strcat('error-',(msgid),'-t.csv')),ie);
                csvwrite(fullfile('errorInfo',strcat('error-',(msgid),'-t.csv')),v.SIM_TIME);



            end
            v.EVENT = ie;
            if v.SEC_RUN  % the model ran in seconds, but results are converted to min
                v.OUTPUT2   = interp1(t, x(:,:),(0:60:t(end)));
                v.SIM_TIME = t(end)/60;
                v.SPECIES{1} = v.OUTPUT2(end,:);
            else % the model ran in minutes
                if length(t)<=1||length(x)<=1
                    fprintf('size of t: %d, size of x: %d\n',length(t),length(x));
                end
                try
                    v.OUTPUT2 = interp1(t, x(:,:),(0:1:t(end)));
                catch ME
                    fprintf('unable to interp due to no output')
                    mkdir 'errorInfo';
                    csvwrite(fullfile('errorInfo',strcat('error-',(msgid),'-initial.csv')),initial);
                    csvwrite(fullfile('errorInfo',strcat('error-',(msgid),'-x.csv')),x);
                end
                %v.SHORTOUTPUT=interp1(t,x(:,:),(0:5:t(end)));
                v.SHORTTIME=(0:5:ceil(t(end)));
%                 v.SHORTOUTPUT = cell(ceil(t(end)/5)+1,length(v.SPECIES{2})+1);
%                 for x = 1:length(v.SPECIES{2})
%                     v.SHORTOUTPUT{1,x+1}=v.SPECIES{2}{x};
%                     for tt = 1:size(fiveMins,1)
%                         v.SHORTOUTPUT{tt+1,x+1}=fiveMins(tt,x);
%                     end
%                 end
%                 for tt = 1:1:size(fiveMins,1)
%                     v.SHORTOUTPUT{tt+1,1} = ((tt-1)*5);
%                 end
%                 v.SHORTOUTPUT{1,1}='Min';
                v.SIM_TIME = t(end);
                v.SPECIES{1} = v.OUTPUT2(end,:);
            end
        else % only running phase 1 to get basal levels
            v.OUTPUT2 = v.OUTPUT1;
        end
end