function [x2,cumulativeSumNFkBv1,allTimeCoursesNFkBv1,startingStatesNFkBv1,v2,rememberActivationStrengths] = runNFkBv1(conditions)
%runs NFkB model version 1

    numSamples=conditions.numSamples;
    maxTime=conditions.maxTime;
    BlimpThreshold=conditions.BlimpThreshold;
    AIDThreshold=conditions.AIDThreshold;
    meanSignal=conditions.meanSignal;
    stdDevSignal=conditions.stdDevSignal;
    NFkBIndependantSignal=conditions.NFkBIndependantSignal;
    NFkBIndependantstdDev=conditions.NFkBIndependantstdDev;
    totalReplicates = conditions.replicates;
    
    time=[1:1:maxTime];
    cumulativeSumNFkBv1=zeros(maxTime,totalReplicates);
    options=odeset('RelTol',1e-12,'AbsTol',1e-12);
    x2=[];
    rememberActivationStrengths=[];
    allTCReplicatesWT={};
    for replicates=1:totalReplicates
        timeOfDifferentiationSumNFkBv1=zeros(1,numSamples);
        allTimeCoursesSumNFkBv1=zeros(7,length(time),numSamples);
        startingStatesNFkBv1=zeros(2,numSamples);

        for i=1:numSamples
            %SIMULATE NFkB V1

            init=[0,0,1,0,0,0,0];

            meane_i=meanSignal;
            sde_i=stdDevSignal*meane_i;
            v2=parametersASCNFkB5();
            v2(6,5)=max(normrnd(meane_i,sde_i),eps);
            v2(7,5)=max(normrnd(meane_i,sde_i),eps);
            startingStatesNFkBv1(1,i)=v2(6,5);
            startingStatesNFkBv1(2,i)=v2(7,5);

            K=(10^9);
            Ag=1024*10^12;
            f=Ag/(K+Ag);
            meane_i=NFkBIndependantSignal*f;
            sde_i=NFkBIndependantstdDev*meane_i*f;
            v2(1,5)=normrnd(meane_i,sde_i);
            if replicates==totalReplicates
                rememberActivationStrengths=[rememberActivationStrengths,v2(1,5)]; 
            end
            [t2,x2]=ode45(@(t,x) ODEWithoutcRelDownreg_02262018(t,x,[],v2), time, init,options);
            names={'IRF4', 'Blimp', 'Pax', 'Bcl', 'AID', 'cRel','relA'};
            for j=1:length(init)
                allTimeCoursesNFkBv1(j,:,i)=x2(:,j)';
            end
            thiTime=[];
            thisTime=find(x2(:,2)>BlimpThreshold,1,'first');
            if(thisTime)
                thisTime2=find(x2(thisTime:end,5)<AIDThreshold,1,'first');
                if(thisTime2)
                    timeOfDifferentiationcRelNFkBv1(i)=thisTime2+thisTime;
                else
                    timeOfDifferentiationcRelNFkBv1(i)=NaN;
                end
            else
                timeOfDifferentiationcRelNFkBv1(i)=NaN;
            end
        end
        experimentTime=[0,24,36,48,60,72];
        sortedNFkBv1=sort(timeOfDifferentiationcRelNFkBv1);
        for i=1:maxTime
            cumulativeSumNFkBv1(i,replicates)=sum(sortedNFkBv1<i)./numSamples;
        end
    end
end