function [x,cumulativeSumSingh,allTimeCoursesSingh] = runSinghModel(conditions)
%runs published model by Singh et al.

    numSamples=conditions.numSamples;
    maxTime=conditions.maxTime;
    BlimpThreshold=conditions.BlimpThreshold;
    AIDThreshold=conditions.AIDThreshold;
    meanSignal=conditions.meanSignal;
    stdDevSignal=conditions.stdDevSignal;
    totalReplicates = conditions.replicates;
    SinghMeanSignal=conditions.SinghMeanSignal;
    SinghStdSignal=conditions.SinghStdSignal;
    
    time=[1:1:maxTime];
    cumulativeSumSingh=zeros(maxTime,totalReplicates);

    rememberActivationStrengths=[];
    
    for replicates=1:totalReplicates
        timeOfDifferentiationSingh=zeros(1,numSamples);
        allTimeCoursesSingh=zeros(7,length(time),numSamples);
        startingStatesSingh=zeros(2,numSamples);
        
        for i=1:numSamples
            %SIMULATE SINGH MODEl
            %IRF4, Blimp, Pax, Bcl, AID, cRel
            K=(10^9);
            Ag=1024*10^12;
            f=Ag/(K+Ag);
            init1=[0,0,1,0,0];
            meane_i=SinghMeanSignal*f;
            sde_i=SinghStdSignal*meane_i*f;
            options=odeset('RelTol',1e-12,'AbsTol',1e-12);
            v=parametersOSC();
            v(1,5)=normrnd(meane_i,sde_i);


            %v(1,5)=0.4;
            [t,x]=ode45(@(t,x) odeASC(t,x,[],v), time, init1,options);

            names={'IRF4', 'Blimp', 'Pax', 'Bcl', 'AID', 'cRel','relA'};
            for j=1:length(init1)
                allTimeCoursesSingh(j,:,i)=x(:,j)';
            end
            thisTime=find(x(:,2)>BlimpThreshold,1,'first');
            if(thisTime)
                thisTime2=find(x(thisTime:end,5)<AIDThreshold,1,'first');
                if(thisTime2)
                    timeOfDifferentiationSingh(i)=thisTime;
                else
                    timeOfDifferentiationSingh(i)=NaN;
                end
            else
                timeOfDifferentiationSingh(i)=NaN;
            end
        sortedSingh=sort(timeOfDifferentiationSingh);
        for i=1:maxTime
            cumulativeSumSingh(i,replicates)=sum(sortedSingh<i)./numSamples;
        end
    end
end